@@ -317,7 +317,7 @@ and agg_reduce typ es c =
     | (coef, e) :: es -> begin
 	match reduce e with
 	  (* Pi ... * 0 ^ coef * ... -> 0 *)
-	  Inte 0 as re when typ = Multe -> (0, [])
+	  Inte 0 when typ = Multe -> (0, [])
 	| Inte i -> agg_reduce_rec new_es (op c (coef_op i coef)) es
 	  (* Sum ... + coef * (Sum ees + ec) + ... -> Sum ... *)
 	  (* Pi ... * (ec * Pi ees) ^ coef * ... -> Pi ... *)
